summaryrefslogtreecommitdiffstats
path: root/views/controls/textfield/native_textfield_win.h
diff options
context:
space:
mode:
authorpinkerton@chromium.org <pinkerton@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-12-04 17:50:26 +0000
committerpinkerton@chromium.org <pinkerton@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-12-04 17:50:26 +0000
commitb284843ba6a1e90c12f91eaf796726433dc2537d (patch)
tree96edc5a4528e4d685c89544bfc13712e2984964a /views/controls/textfield/native_textfield_win.h
parente83ce1e3f2fcacb3d400287d78567d22a2a06cae (diff)
downloadchromium_src-b284843ba6a1e90c12f91eaf796726433dc2537d.zip
chromium_src-b284843ba6a1e90c12f91eaf796726433dc2537d.tar.gz
chromium_src-b284843ba6a1e90c12f91eaf796726433dc2537d.tar.bz2
Refactor the menu model to live outside views/ so it can be shared
BUG=none TEST=none Review URL: http://codereview.chromium.org/465005 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@33827 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'views/controls/textfield/native_textfield_win.h')
-rw-r--r--views/controls/textfield/native_textfield_win.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/views/controls/textfield/native_textfield_win.h b/views/controls/textfield/native_textfield_win.h
index a291a71..a5fb887 100644
--- a/views/controls/textfield/native_textfield_win.h
+++ b/views/controls/textfield/native_textfield_win.h
@@ -14,14 +14,15 @@
#include <vsstyle.h>
#include "app/gfx/insets.h"
+#include "app/menus/simple_menu_model.h"
#include "base/scoped_comptr_win.h"
-#include "views/controls/menu/simple_menu_model.h"
#include "views/controls/textfield/native_textfield_wrapper.h"
namespace views {
class NativeViewHost;
class Textfield;
+class Menu2;
static const int kDefaultEditStyle = WS_CHILD | WS_VISIBLE | WS_CLIPCHILDREN |
WS_CLIPSIBLINGS;
@@ -32,7 +33,7 @@ class NativeTextfieldWin
CWinTraits<kDefaultEditStyle> >,
public CRichEditCommands<NativeTextfieldWin>,
public NativeTextfieldWrapper,
- public SimpleMenuModel::Delegate {
+ public menus::SimpleMenuModel::Delegate {
public:
DECLARE_WND_CLASS(L"ViewsTextfieldEdit");
@@ -61,11 +62,11 @@ class NativeTextfieldWin
virtual View* GetView();
virtual gfx::NativeView GetTestingHandle() const;
// Overridden from SimpleMenuModel::Delegate:
virtual bool IsCommandIdChecked(int command_id) const;
virtual bool IsCommandIdEnabled(int command_id) const;
virtual bool GetAcceleratorForCommandId(int command_id,
- Accelerator* accelerator);
+ menus::Accelerator* accelerator);
virtual void ExecuteCommand(int command_id);
// CWindowImpl
@@ -193,7 +194,7 @@ class NativeTextfieldWin
static bool did_load_library_;
// The contents of the context menu for the edit.
- scoped_ptr<SimpleMenuModel> context_menu_contents_;
+ scoped_ptr<menus::SimpleMenuModel> context_menu_contents_;
scoped_ptr<Menu2> context_menu_;
// Border insets.
@@ -61,11 +62,11 @@ class NativeTextfieldWin
virtual View* GetView();
virtual gfx::NativeView GetTestingHandle() const;
- // Overridden from SimpleMenuModel::Delegate:
+ // Overridden from menus::SimpleMenuModel::Delegate:
virtual bool IsCommandIdChecked(int command_id) const;
virtual bool IsCommandIdEnabled(int command_id) const;